@@ -1,14 +1,8 @@
 import unittest
 
 import web
-from web.py3helpers import PY2
 from web.template import SecurityError, Template
 
-try:
-    unicode  # Python 2
-except NameError:
-    unicode = str  # Python 3
-
 
 class _TestResult:
     def __init__(self, t):
@@ -18,7 +12,7 @@ class _TestResult:
         return getattr(self.t, name)
 
     def __repr__(self):
-        return repr(unicode(self.t))
+        return repr(str(self.t))
 
 
 def t(code, **keywords):
@@ -30,18 +24,8 @@ class TemplateTest(unittest.TestCase):
     """Tests for the template security feature."""
 
     def testPrint(self):
-        if PY2:
-            tpl = "$code:\n    print 'blah'"
-            # print_function has been imported from __future__ so the print statement doesn't exist anymore
-            self.assertRaises(SyntaxError, t, tpl)
-        else:
-            tpl = "$code:\n    print('blah')"
-            self.assertRaises(NameError, t(tpl))
-
-    def testRepr(self):
-        if PY2:  # this feature doesn't exist in Py3 anymore
-            tpl = "$code:\n    `1`"
-            self.assertRaises(SecurityError, t, tpl)
+        tpl = "$code:\n    print('blah')"
+        self.assertRaises(NameError, t(tpl))
 
     def testAttr(self):
         tpl = "$code:\n    (lambda x: x+1).func_code"
@@ -52,8 +36,7 @@ class TemplateTest(unittest.TestCase):
 
         # these two should execute themselves flawlessly
         t("$code:\n    foo = {'a': 1}.items()")()
-        if not PY2:
-            t("$code:\n    bar = {k:0 for k in [1,2,3]}")()
+        t("$code:\n    bar = {k:0 for k in [1,2,3]}")()
 
 
 class TestRender:
